=============================
Text with moving letters
=============================

I think this example illustrates well the interest of script-based editing (imagine doing that by hand).

.. raw:: html

        <div style="position: relative; padding-bottom: 56.25%; padding-top: 30px; margin-bottom:30px; height: 0; overflow: hidden; margin-left: 5%;"><iframe type="text/html" src="https://www.youtube.com/embed/jj5qrHl5ZS0" frameborder="0" style="position: absolute; top: 0; bottom: 10; width: 90%; height: 100%;" allowfullscreen></iframe></div>

Here is the code:

.. literalinclude:: ../../examples/moving_letters.py
